# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quote/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fquote/api.proto\x12\x16longbridgeapp.quote.v1\")\n\x0fSecurityRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\".\n\x14MultiSecurityRequest\x12\x16\n\x06symbol\x18\x01 \x03(\tR\x06symbol\"j\n\x1aSecurityStaticInfoResponse\x12L\n\x10secu_static_info\x18\x01 \x03(\x0b\x32\".longbridgeapp.quote.v1.StaticInfoR\x0esecuStaticInfo\"\xe5\x03\n\nStaticInfo\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x17\n\x07name_cn\x18\x02 \x01(\tR\x06nameCn\x12\x17\n\x07name_en\x18\x03 \x01(\tR\x06nameEn\x12\x17\n\x07name_hk\x18\x04 \x01(\tR\x06nameHk\x12!\n\x0clisting_date\x18\x05 \x01(\tR\x0blistingDate\x12\x1a\n\x08\x65xchange\x18\x06 \x01(\tR\x08\x65xchange\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x19\n\x08lot_size\x18\x08 \x01(\x05R\x07lotSize\x12!\n\x0ctotal_shares\x18\t \x01(\x03R\x0btotalShares\x12-\n\x12\x63irculating_shares\x18\n \x01(\x03R\x11\x63irculatingShares\x12\x1b\n\thk_shares\x18\x0b \x01(\x03R\x08hkShares\x12\x10\n\x03\x65ps\x18\x0c \x01(\tR\x03\x65ps\x12\x17\n\x07\x65ps_ttm\x18\r \x01(\tR\x06\x65psTtm\x12\x10\n\x03\x62ps\x18\x0e \x01(\tR\x03\x62ps\x12%\n\x0e\x64ividend_yield\x18\x0f \x01(\tR\rdividendYield\x12+\n\x11stock_derivatives\x18\x10 \x03(\x05R\x10stockDerivatives\"]\n\x15SecurityQuoteResponse\x12\x44\n\nsecu_quote\x18\x01 \x03(\x0b\x32%.longbridgeapp.quote.v1.SecurityQuoteR\tsecuQuote\"\xd9\x03\n\rSecurityQuote\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1b\n\tlast_done\x18\x02 \x01(\tR\x08lastDone\x12\x1d\n\nprev_close\x18\x03 \x01(\tR\tprevClose\x12\x12\n\x04open\x18\x04 \x01(\tR\x04open\x12\x12\n\x04high\x18\x05 \x01(\tR\x04high\x12\x10\n\x03low\x18\x06 \x01(\tR\x03low\x12\x1c\n\ttimestamp\x18\x07 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x08 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\t \x01(\tR\x08turnover\x12\x46\n\x0ctrade_status\x18\n \x01(\x0e\x32#.longbridgeapp.quote.v1.TradeStatusR\x0btradeStatus\x12N\n\x10pre_market_quote\x18\x0b \x01(\x0b\x32$.longbridgeapp.quote.v1.PrePostQuoteR\x0epreMarketQuote\x12P\n\x11post_market_quote\x18\x0c \x01(\x0b\x32$.longbridgeapp.quote.v1.PrePostQuoteR\x0fpostMarketQuote\"\xc2\x01\n\x0cPrePostQuote\x12\x1b\n\tlast_done\x18\x01 \x01(\tR\x08lastDone\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x03 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\x04 \x01(\tR\x08turnover\x12\x12\n\x04high\x18\x05 \x01(\tR\x04high\x12\x10\n\x03low\x18\x06 \x01(\tR\x03low\x12\x1d\n\nprev_close\x18\x07 \x01(\tR\tprevClose\"Y\n\x13OptionQuoteResponse\x12\x42\n\nsecu_quote\x18\x01 \x03(\x0b\x32#.longbridgeapp.quote.v1.OptionQuoteR\tsecuQuote\"\x80\x03\n\x0bOptionQuote\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1b\n\tlast_done\x18\x02 \x01(\tR\x08lastDone\x12\x1d\n\nprev_close\x18\x03 \x01(\tR\tprevClose\x12\x12\n\x04open\x18\x04 \x01(\tR\x04open\x12\x12\n\x04high\x18\x05 \x01(\tR\x04high\x12\x10\n\x03low\x18\x06 \x01(\tR\x03low\x12\x1c\n\ttimestamp\x18\x07 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x08 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\t \x01(\tR\x08turnover\x12\x46\n\x0ctrade_status\x18\n \x01(\x0e\x32#.longbridgeapp.quote.v1.TradeStatusR\x0btradeStatus\x12I\n\roption_extend\x18\x0b \x01(\x0b\x32$.longbridgeapp.quote.v1.OptionExtendR\x0coptionExtend\"\xa1\x03\n\x0cOptionExtend\x12-\n\x12implied_volatility\x18\x01 \x01(\tR\x11impliedVolatility\x12#\n\ropen_interest\x18\x02 \x01(\x03R\x0copenInterest\x12\x1f\n\x0b\x65xpiry_date\x18\x03 \x01(\tR\nexpiryDate\x12!\n\x0cstrike_price\x18\x04 \x01(\tR\x0bstrikePrice\x12/\n\x13\x63ontract_multiplier\x18\x05 \x01(\tR\x12\x63ontractMultiplier\x12#\n\rcontract_type\x18\x06 \x01(\tR\x0c\x63ontractType\x12#\n\rcontract_size\x18\x07 \x01(\tR\x0c\x63ontractSize\x12\x1c\n\tdirection\x18\x08 \x01(\tR\tdirection\x12\x33\n\x15historical_volatility\x18\t \x01(\tR\x14historicalVolatility\x12+\n\x11underlying_symbol\x18\n \x01(\tR\x10underlyingSymbol\"[\n\x14WarrantQuoteResponse\x12\x43\n\nsecu_quote\x18\x02 \x03(\x0b\x32$.longbridgeapp.quote.v1.WarrantQuoteR\tsecuQuote\"\x84\x03\n\x0cWarrantQuote\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1b\n\tlast_done\x18\x02 \x01(\tR\x08lastDone\x12\x1d\n\nprev_close\x18\x03 \x01(\tR\tprevClose\x12\x12\n\x04open\x18\x04 \x01(\tR\x04open\x12\x12\n\x04high\x18\x05 \x01(\tR\x04high\x12\x10\n\x03low\x18\x06 \x01(\tR\x03low\x12\x1c\n\ttimestamp\x18\x07 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x08 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\t \x01(\tR\x08turnover\x12\x46\n\x0ctrade_status\x18\n \x01(\x0e\x32#.longbridgeapp.quote.v1.TradeStatusR\x0btradeStatus\x12L\n\x0ewarrant_extend\x18\x0b \x01(\x0b\x32%.longbridgeapp.quote.v1.WarrantExtendR\rwarrantExtend\"\xef\x03\n\rWarrantExtend\x12-\n\x12implied_volatility\x18\x01 \x01(\tR\x11impliedVolatility\x12\x1f\n\x0b\x65xpiry_date\x18\x02 \x01(\tR\nexpiryDate\x12&\n\x0flast_trade_date\x18\x03 \x01(\tR\rlastTradeDate\x12+\n\x11outstanding_ratio\x18\x04 \x01(\tR\x10outstandingRatio\x12\'\n\x0foutstanding_qty\x18\x05 \x01(\x03R\x0eoutstandingQty\x12)\n\x10\x63onversion_ratio\x18\x06 \x01(\tR\x0f\x63onversionRatio\x12\x1a\n\x08\x63\x61tegory\x18\x07 \x01(\tR\x08\x63\x61tegory\x12!\n\x0cstrike_price\x18\x08 \x01(\tR\x0bstrikePrice\x12,\n\x12upper_strike_price\x18\t \x01(\tR\x10upperStrikePrice\x12,\n\x12lower_strike_price\x18\n \x01(\tR\x10lowerStrikePrice\x12\x1d\n\ncall_price\x18\x0b \x01(\tR\tcallPrice\x12+\n\x11underlying_symbol\x18\x0c \x01(\tR\x10underlyingSymbol\"\x91\x01\n\x15SecurityDepthResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12/\n\x03\x61sk\x18\x02 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.DepthR\x03\x61sk\x12/\n\x03\x62id\x18\x03 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.DepthR\x03\x62id\"n\n\x05\x44\x65pth\x12\x1a\n\x08position\x18\x01 \x01(\x05R\x08position\x12\x14\n\x05price\x18\x02 \x01(\tR\x05price\x12\x16\n\x06volume\x18\x03 \x01(\x03R\x06volume\x12\x1b\n\torder_num\x18\x04 \x01(\x03R\x08orderNum\"\xb5\x01\n\x17SecurityBrokersResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12@\n\x0b\x61sk_brokers\x18\x02 \x03(\x0b\x32\x1f.longbridgeapp.quote.v1.BrokersR\naskBrokers\x12@\n\x0b\x62id_brokers\x18\x03 \x03(\x0b\x32\x1f.longbridgeapp.quote.v1.BrokersR\nbidBrokers\"D\n\x07\x42rokers\x12\x1a\n\x08position\x18\x01 \x01(\x05R\x08position\x12\x1d\n\nbroker_ids\x18\x02 \x03(\x05R\tbrokerIds\"\x85\x01\n\x1cParticipantBrokerIdsResponse\x12\x65\n\x1aparticipant_broker_numbers\x18\x01 \x03(\x0b\x32\'.longbridgeapp.quote.v1.ParticipantInfoR\x18participantBrokerNumbers\"\xc0\x01\n\x0fParticipantInfo\x12\x1d\n\nbroker_ids\x18\x01 \x03(\x05R\tbrokerIds\x12.\n\x13participant_name_cn\x18\x02 \x01(\tR\x11participantNameCn\x12.\n\x13participant_name_en\x18\x03 \x01(\tR\x11participantNameEn\x12.\n\x13participant_name_hk\x18\x04 \x01(\tR\x11participantNameHk\"D\n\x14SecurityTradeRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x14\n\x05\x63ount\x18\x02 \x01(\x05R\x05\x63ount\"f\n\x15SecurityTradeResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x35\n\x06trades\x18\x02 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.TradeR\x06trades\"\xdb\x01\n\x05Trade\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x16\n\x06volume\x18\x02 \x01(\x03R\x06volume\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12\x1d\n\ntrade_type\x18\x04 \x01(\tR\ttradeType\x12\x1c\n\tdirection\x18\x05 \x01(\x05R\tdirection\x12I\n\rtrade_session\x18\x06 \x01(\x0e\x32$.longbridgeapp.quote.v1.TradeSessionR\x0ctradeSession\"1\n\x17SecurityIntradayRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\"f\n\x18SecurityIntradayResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x32\n\x05lines\x18\x02 \x03(\x0b\x32\x1c.longbridgeapp.quote.v1.LineR\x05lines\"\x8b\x01\n\x04Line\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x03 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\x04 \x01(\tR\x08turnover\x12\x1b\n\tavg_price\x18\x05 \x01(\tR\x08\x61vgPrice\"\xc7\x01\n\x1aSecurityCandlestickRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x36\n\x06period\x18\x02 \x01(\x0e\x32\x1e.longbridgeapp.quote.v1.PeriodR\x06period\x12\x14\n\x05\x63ount\x18\x03 \x01(\x05R\x05\x63ount\x12\x43\n\x0b\x61\x64just_type\x18\x04 \x01(\x0e\x32\".longbridgeapp.quote.v1.AdjustTypeR\nadjustType\"~\n\x1bSecurityCandlestickResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12G\n\x0c\x63\x61ndlesticks\x18\x02 \x03(\x0b\x32#.longbridgeapp.quote.v1.CandlestickR\x0c\x63\x61ndlesticks\"\xaf\x01\n\x0b\x43\x61ndlestick\x12\x14\n\x05\x63lose\x18\x01 \x01(\tR\x05\x63lose\x12\x12\n\x04open\x18\x02 \x01(\tR\x04open\x12\x10\n\x03low\x18\x03 \x01(\tR\x03low\x12\x12\n\x04high\x18\x04 \x01(\tR\x04high\x12\x16\n\x06volume\x18\x05 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\x06 \x01(\tR\x08turnover\x12\x1c\n\ttimestamp\x18\x07 \x01(\x03R\ttimestamp\">\n\x1bOptionChainDateListResponse\x12\x1f\n\x0b\x65xpiry_date\x18\x01 \x03(\tR\nexpiryDate\"[\n OptionChainDateStrikeInfoRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1f\n\x0b\x65xpiry_date\x18\x02 \x01(\tR\nexpiryDate\"x\n!OptionChainDateStrikeInfoResponse\x12S\n\x11strike_price_info\x18\x01 \x03(\x0b\x32\'.longbridgeapp.quote.v1.StrikePriceInfoR\x0fstrikePriceInfo\"\x83\x01\n\x0fStrikePriceInfo\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1f\n\x0b\x63\x61ll_symbol\x18\x02 \x01(\tR\ncallSymbol\x12\x1d\n\nput_symbol\x18\x03 \x01(\tR\tputSymbol\x12\x1a\n\x08standard\x18\x04 \x01(\x08R\x08standard\"Y\n\x12IssuerInfoResponse\x12\x43\n\x0bissuer_info\x18\x01 \x03(\x0b\x32\".longbridgeapp.quote.v1.IssuerInfoR\nissuerInfo\"g\n\nIssuerInfo\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x17\n\x07name_cn\x18\x02 \x01(\tR\x06nameCn\x12\x17\n\x07name_en\x18\x03 \x01(\tR\x06nameEn\x12\x17\n\x07name_hk\x18\x04 \x01(\tR\x06nameHk\"\x99\x01\n\x18WarrantFilterListRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12I\n\rfilter_config\x18\x02 \x01(\x0b\x32$.longbridgeapp.quote.v1.FilterConfigR\x0c\x66ilterConfig\x12\x1a\n\x08language\x18\x03 \x01(\x05R\x08language\"\x8a\x02\n\x0c\x46ilterConfig\x12\x17\n\x07sort_by\x18\x01 \x01(\x05R\x06sortBy\x12\x1d\n\nsort_order\x18\x02 \x01(\x05R\tsortOrder\x12\x1f\n\x0bsort_offset\x18\x03 \x01(\x05R\nsortOffset\x12\x1d\n\nsort_count\x18\x04 \x01(\x05R\tsortCount\x12\x12\n\x04type\x18\x05 \x03(\x05R\x04type\x12\x16\n\x06issuer\x18\x06 \x03(\x05R\x06issuer\x12\x1f\n\x0b\x65xpiry_date\x18\x07 \x03(\x05R\nexpiryDate\x12\x1d\n\nprice_type\x18\x08 \x03(\x05R\tpriceType\x12\x16\n\x06status\x18\t \x03(\x05R\x06status\"\x86\x01\n\x19WarrantFilterListResponse\x12H\n\x0cwarrant_list\x18\x01 \x03(\x0b\x32%.longbridgeapp.quote.v1.FilterWarrantR\x0bwarrantList\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x05R\ntotalCount\"\xb9\x06\n\rFilterWarrant\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1b\n\tlast_done\x18\x03 \x01(\tR\x08lastDone\x12\x1f\n\x0b\x63hange_rate\x18\x04 \x01(\tR\nchangeRate\x12\x1d\n\nchange_val\x18\x05 \x01(\tR\tchangeVal\x12\x16\n\x06volume\x18\x06 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\x07 \x01(\tR\x08turnover\x12\x1f\n\x0b\x65xpiry_date\x18\x08 \x01(\tR\nexpiryDate\x12!\n\x0cstrike_price\x18\t \x01(\tR\x0bstrikePrice\x12,\n\x12upper_strike_price\x18\n \x01(\tR\x10upperStrikePrice\x12,\n\x12lower_strike_price\x18\x0b \x01(\tR\x10lowerStrikePrice\x12\'\n\x0foutstanding_qty\x18\x0c \x01(\tR\x0eoutstandingQty\x12+\n\x11outstanding_ratio\x18\r \x01(\tR\x10outstandingRatio\x12\x18\n\x07premium\x18\x0e \x01(\tR\x07premium\x12\x17\n\x07itm_otm\x18\x0f \x01(\tR\x06itmOtm\x12-\n\x12implied_volatility\x18\x10 \x01(\tR\x11impliedVolatility\x12\x14\n\x05\x64\x65lta\x18\x11 \x01(\tR\x05\x64\x65lta\x12\x1d\n\ncall_price\x18\x12 \x01(\tR\tcallPrice\x12\"\n\rto_call_price\x18\x13 \x01(\tR\x0btoCallPrice\x12-\n\x12\x65\x66\x66\x65\x63tive_leverage\x18\x14 \x01(\tR\x11\x65\x66\x66\x65\x63tiveLeverage\x12%\n\x0eleverage_ratio\x18\x15 \x01(\tR\rleverageRatio\x12)\n\x10\x63onversion_ratio\x18\x16 \x01(\tR\x0f\x63onversionRatio\x12#\n\rbalance_point\x18\x17 \x01(\tR\x0c\x62\x61lancePoint\x12\x14\n\x05state\x18\x18 \x01(\tR\x05state\"x\n\x19MarketTradePeriodResponse\x12[\n\x14market_trade_session\x18\x01 \x03(\x0b\x32).longbridgeapp.quote.v1.MarketTradePeriodR\x12marketTradeSession\"u\n\x11MarketTradePeriod\x12\x16\n\x06market\x18\x01 \x01(\tR\x06market\x12H\n\rtrade_session\x18\x02 \x03(\x0b\x32#.longbridgeapp.quote.v1.TradePeriodR\x0ctradeSession\"\x8e\x01\n\x0bTradePeriod\x12\x19\n\x08\x62\x65g_time\x18\x01 \x01(\x05R\x07\x62\x65gTime\x12\x19\n\x08\x65nd_time\x18\x02 \x01(\x05R\x07\x65ndTime\x12I\n\rtrade_session\x18\x03 \x01(\x0e\x32$.longbridgeapp.quote.v1.TradeSessionR\x0ctradeSession\"\x15\n\x13SubscriptionRequest\"V\n\x14SubscriptionResponse\x12>\n\x08sub_list\x18\x01 \x03(\x0b\x32#.longbridgeapp.quote.v1.SubTypeListR\x07subList\"a\n\x0bSubTypeList\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12:\n\x08sub_type\x18\x02 \x03(\x0e\x32\x1f.longbridgeapp.quote.v1.SubTypeR\x07subType\"\x8a\x01\n\x10SubscribeRequest\x12\x16\n\x06symbol\x18\x01 \x03(\tR\x06symbol\x12:\n\x08sub_type\x18\x02 \x03(\x0e\x32\x1f.longbridgeapp.quote.v1.SubTypeR\x07subType\x12\"\n\ris_first_push\x18\x03 \x01(\x08R\x0bisFirstPush\"\x85\x01\n\x12UnsubscribeRequest\x12\x16\n\x06symbol\x18\x01 \x03(\tR\x06symbol\x12:\n\x08sub_type\x18\x02 \x03(\x0e\x32\x1f.longbridgeapp.quote.v1.SubTypeR\x07subType\x12\x1b\n\tunsub_all\x18\x03 \x01(\x08R\x08unsubAll\"\x15\n\x13UnsubscribeResponse\"\xfb\x02\n\tPushQuote\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1a\n\x08sequence\x18\x02 \x01(\x03R\x08sequence\x12\x1b\n\tlast_done\x18\x03 \x01(\tR\x08lastDone\x12\x12\n\x04open\x18\x04 \x01(\tR\x04open\x12\x12\n\x04high\x18\x05 \x01(\tR\x04high\x12\x10\n\x03low\x18\x06 \x01(\tR\x03low\x12\x1c\n\ttimestamp\x18\x07 \x01(\x03R\ttimestamp\x12\x16\n\x06volume\x18\x08 \x01(\x03R\x06volume\x12\x1a\n\x08turnover\x18\t \x01(\tR\x08turnover\x12\x46\n\x0ctrade_status\x18\n \x01(\x0e\x32#.longbridgeapp.quote.v1.TradeStatusR\x0btradeStatus\x12I\n\rtrade_session\x18\x0b \x01(\x0e\x32$.longbridgeapp.quote.v1.TradeSessionR\x0ctradeSession\"\xa1\x01\n\tPushDepth\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1a\n\x08sequence\x18\x02 \x01(\x03R\x08sequence\x12/\n\x03\x61sk\x18\x03 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.DepthR\x03\x61sk\x12/\n\x03\x62id\x18\x04 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.DepthR\x03\x62id\"\xc5\x01\n\x0bPushBrokers\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1a\n\x08sequence\x18\x02 \x01(\x03R\x08sequence\x12@\n\x0b\x61sk_brokers\x18\x03 \x03(\x0b\x32\x1f.longbridgeapp.quote.v1.BrokersR\naskBrokers\x12@\n\x0b\x62id_brokers\x18\x04 \x03(\x0b\x32\x1f.longbridgeapp.quote.v1.BrokersR\nbidBrokers\"t\n\tPushTrade\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1a\n\x08sequence\x18\x02 \x01(\x03R\x08sequence\x12\x33\n\x05trade\x18\x03 \x03(\x0b\x32\x1d.longbridgeapp.quote.v1.TradeR\x05trade\"a\n\x15MarketTradeDayRequest\x12\x16\n\x06market\x18\x01 \x01(\tR\x06market\x12\x17\n\x07\x62\x65g_day\x18\x02 \x01(\tR\x06\x62\x65gDay\x12\x17\n\x07\x65nd_day\x18\x03 \x01(\tR\x06\x65ndDay\"[\n\x16MarketTradeDayResponse\x12\x1b\n\ttrade_day\x18\x01 \x03(\tR\x08tradeDay\x12$\n\x0ehalf_trade_day\x18\x02 \x03(\tR\x0chalfTradeDay*\xce\x04\n\x07\x43ommand\x12\x13\n\x0fUNKNOWN_COMMAND\x10\x00\x12\x0e\n\nHEART_BEAT\x10\x01\x12\x08\n\x04\x41UTH\x10\x02\x12\r\n\tRECONNECT\x10\x03\x12\x10\n\x0cSubscription\x10\x05\x12\r\n\tSubscribe\x10\x06\x12\x0f\n\x0bUnsubscribe\x10\x07\x12\x1a\n\x16QueryMarketTradePeriod\x10\x08\x12\x17\n\x13QueryMarketTradeDay\x10\t\x12\x1b\n\x17QuerySecurityStaticInfo\x10\n\x12\x16\n\x12QuerySecurityQuote\x10\x0b\x12\x14\n\x10QueryOptionQuote\x10\x0c\x12\x15\n\x11QueryWarrantQuote\x10\r\x12\x0e\n\nQueryDepth\x10\x0e\x12\x10\n\x0cQueryBrokers\x10\x0f\x12\x1d\n\x19QueryParticipantBrokerIds\x10\x10\x12\x0e\n\nQueryTrade\x10\x11\x12\x11\n\rQueryIntraday\x10\x12\x12\x14\n\x10QueryCandlestick\x10\x13\x12\x18\n\x14QueryOptionChainDate\x10\x14\x12\"\n\x1eQueryOptionChainDateStrikeInfo\x10\x15\x12\x1a\n\x16QueryWarrantIssuerInfo\x10\x16\x12\x1a\n\x16QueryWarrantFilterList\x10\x17\x12\x11\n\rPushQuoteData\x10\x65\x12\x11\n\rPushDepthData\x10\x66\x12\x13\n\x0fPushBrokersData\x10g\x12\x11\n\rPushTradeData\x10h*\xc2\x01\n\x0bTradeStatus\x12\n\n\x06NORMAL\x10\x00\x12\n\n\x06HALTED\x10\x01\x12\x0c\n\x08\x44\x45LISTED\x10\x02\x12\x08\n\x04\x46USE\x10\x03\x12\x10\n\x0cPREPARE_LIST\x10\x04\x12\x0e\n\nCODE_MOVED\x10\x05\x12\x10\n\x0cTO_BE_OPENED\x10\x06\x12\x15\n\x11SPLIT_STOCK_HALTS\x10\x07\x12\x0b\n\x07\x45XPIRED\x10\x08\x12\x18\n\x14WARRANT_PREPARE_LIST\x10\t\x12\x11\n\rSUSPEND_TRADE\x10\n*?\n\x0cTradeSession\x12\x10\n\x0cNORMAL_TRADE\x10\x00\x12\r\n\tPRE_TRADE\x10\x01\x12\x0e\n\nPOST_TRADE\x10\x02*/\n\nAdjustType\x12\r\n\tNO_ADJUST\x10\x00\x12\x12\n\x0e\x46ORWARD_ADJUST\x10\x01*\xa2\x01\n\x06Period\x12\x12\n\x0eUNKNOWN_PERIOD\x10\x00\x12\x0e\n\nONE_MINUTE\x10\x01\x12\x0f\n\x0b\x46IVE_MINUTE\x10\x05\x12\x12\n\x0e\x46IFTEEN_MINUTE\x10\x0f\x12\x11\n\rTHIRTY_MINUTE\x10\x1e\x12\x10\n\x0cSIXTY_MINUTE\x10<\x12\x08\n\x03\x44\x41Y\x10\xe8\x07\x12\t\n\x04WEEK\x10\xd0\x0f\x12\n\n\x05MONTH\x10\xb8\x17\x12\t\n\x04YEAR\x10\xa0\x1f*I\n\x07SubType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05QUOTE\x10\x01\x12\t\n\x05\x44\x45PTH\x10\x02\x12\x0b\n\x07\x42ROKERS\x10\x03\x12\t\n\x05TRADE\x10\x04\x42\xe1\x01\n\x1a\x63om.longbridgeapp.quote.v1B\x08\x41piProtoP\x01Z?github.com/longbridgeapp/openapi-protobufs/gen/go/quote;quotev1\xa2\x02\x03LQX\xaa\x02\x16Longbridgeapp.Quote.V1\xca\x02\x16Longbridgeapp\\Quote\\V1\xe2\x02\"Longbridgeapp\\Quote\\V1\\GPBMetadata\xea\x02\x18Longbridgeapp::Quote::V1b\x06proto3')

_COMMAND = DESCRIPTOR.enum_types_by_name['Command']
Command = enum_type_wrapper.EnumTypeWrapper(_COMMAND)
_TRADESTATUS = DESCRIPTOR.enum_types_by_name['TradeStatus']
TradeStatus = enum_type_wrapper.EnumTypeWrapper(_TRADESTATUS)
_TRADESESSION = DESCRIPTOR.enum_types_by_name['TradeSession']
TradeSession = enum_type_wrapper.EnumTypeWrapper(_TRADESESSION)
_ADJUSTTYPE = DESCRIPTOR.enum_types_by_name['AdjustType']
AdjustType = enum_type_wrapper.EnumTypeWrapper(_ADJUSTTYPE)
_PERIOD = DESCRIPTOR.enum_types_by_name['Period']
Period = enum_type_wrapper.EnumTypeWrapper(_PERIOD)
_SUBTYPE = DESCRIPTOR.enum_types_by_name['SubType']
SubType = enum_type_wrapper.EnumTypeWrapper(_SUBTYPE)
UNKNOWN_COMMAND = 0
HEART_BEAT = 1
AUTH = 2
RECONNECT = 3
Subscription = 5
Subscribe = 6
Unsubscribe = 7
QueryMarketTradePeriod = 8
QueryMarketTradeDay = 9
QuerySecurityStaticInfo = 10
QuerySecurityQuote = 11
QueryOptionQuote = 12
QueryWarrantQuote = 13
QueryDepth = 14
QueryBrokers = 15
QueryParticipantBrokerIds = 16
QueryTrade = 17
QueryIntraday = 18
QueryCandlestick = 19
QueryOptionChainDate = 20
QueryOptionChainDateStrikeInfo = 21
QueryWarrantIssuerInfo = 22
QueryWarrantFilterList = 23
PushQuoteData = 101
PushDepthData = 102
PushBrokersData = 103
PushTradeData = 104
NORMAL = 0
HALTED = 1
DELISTED = 2
FUSE = 3
PREPARE_LIST = 4
CODE_MOVED = 5
TO_BE_OPENED = 6
SPLIT_STOCK_HALTS = 7
EXPIRED = 8
WARRANT_PREPARE_LIST = 9
SUSPEND_TRADE = 10
NORMAL_TRADE = 0
PRE_TRADE = 1
POST_TRADE = 2
NO_ADJUST = 0
FORWARD_ADJUST = 1
UNKNOWN_PERIOD = 0
ONE_MINUTE = 1
FIVE_MINUTE = 5
FIFTEEN_MINUTE = 15
THIRTY_MINUTE = 30
SIXTY_MINUTE = 60
DAY = 1000
WEEK = 2000
MONTH = 3000
YEAR = 4000
UNKNOWN_TYPE = 0
QUOTE = 1
DEPTH = 2
BROKERS = 3
TRADE = 4


_SECURITYREQUEST = DESCRIPTOR.message_types_by_name['SecurityRequest']
_MULTISECURITYREQUEST = DESCRIPTOR.message_types_by_name['MultiSecurityRequest']
_SECURITYSTATICINFORESPONSE = DESCRIPTOR.message_types_by_name['SecurityStaticInfoResponse']
_STATICINFO = DESCRIPTOR.message_types_by_name['StaticInfo']
_SECURITYQUOTERESPONSE = DESCRIPTOR.message_types_by_name['SecurityQuoteResponse']
_SECURITYQUOTE = DESCRIPTOR.message_types_by_name['SecurityQuote']
_PREPOSTQUOTE = DESCRIPTOR.message_types_by_name['PrePostQuote']
_OPTIONQUOTERESPONSE = DESCRIPTOR.message_types_by_name['OptionQuoteResponse']
_OPTIONQUOTE = DESCRIPTOR.message_types_by_name['OptionQuote']
_OPTIONEXTEND = DESCRIPTOR.message_types_by_name['OptionExtend']
_WARRANTQUOTERESPONSE = DESCRIPTOR.message_types_by_name['WarrantQuoteResponse']
_WARRANTQUOTE = DESCRIPTOR.message_types_by_name['WarrantQuote']
_WARRANTEXTEND = DESCRIPTOR.message_types_by_name['WarrantExtend']
_SECURITYDEPTHRESPONSE = DESCRIPTOR.message_types_by_name['SecurityDepthResponse']
_DEPTH = DESCRIPTOR.message_types_by_name['Depth']
_SECURITYBROKERSRESPONSE = DESCRIPTOR.message_types_by_name['SecurityBrokersResponse']
_BROKERS = DESCRIPTOR.message_types_by_name['Brokers']
_PARTICIPANTBROKERIDSRESPONSE = DESCRIPTOR.message_types_by_name['ParticipantBrokerIdsResponse']
_PARTICIPANTINFO = DESCRIPTOR.message_types_by_name['ParticipantInfo']
_SECURITYTRADEREQUEST = DESCRIPTOR.message_types_by_name['SecurityTradeRequest']
_SECURITYTRADERESPONSE = DESCRIPTOR.message_types_by_name['SecurityTradeResponse']
_TRADE = DESCRIPTOR.message_types_by_name['Trade']
_SECURITYINTRADAYREQUEST = DESCRIPTOR.message_types_by_name['SecurityIntradayRequest']
_SECURITYINTRADAYRESPONSE = DESCRIPTOR.message_types_by_name['SecurityIntradayResponse']
_LINE = DESCRIPTOR.message_types_by_name['Line']
_SECURITYCANDLESTICKREQUEST = DESCRIPTOR.message_types_by_name['SecurityCandlestickRequest']
_SECURITYCANDLESTICKRESPONSE = DESCRIPTOR.message_types_by_name['SecurityCandlestickResponse']
_CANDLESTICK = DESCRIPTOR.message_types_by_name['Candlestick']
_OPTIONCHAINDATELISTRESPONSE = DESCRIPTOR.message_types_by_name['OptionChainDateListResponse']
_OPTIONCHAINDATESTRIKEINFOREQUEST = DESCRIPTOR.message_types_by_name['OptionChainDateStrikeInfoRequest']
_OPTIONCHAINDATESTRIKEINFORESPONSE = DESCRIPTOR.message_types_by_name['OptionChainDateStrikeInfoResponse']
_STRIKEPRICEINFO = DESCRIPTOR.message_types_by_name['StrikePriceInfo']
_ISSUERINFORESPONSE = DESCRIPTOR.message_types_by_name['IssuerInfoResponse']
_ISSUERINFO = DESCRIPTOR.message_types_by_name['IssuerInfo']
_WARRANTFILTERLISTREQUEST = DESCRIPTOR.message_types_by_name['WarrantFilterListRequest']
_FILTERCONFIG = DESCRIPTOR.message_types_by_name['FilterConfig']
_WARRANTFILTERLISTRESPONSE = DESCRIPTOR.message_types_by_name['WarrantFilterListResponse']
_FILTERWARRANT = DESCRIPTOR.message_types_by_name['FilterWarrant']
_MARKETTRADEPERIODRESPONSE = DESCRIPTOR.message_types_by_name['MarketTradePeriodResponse']
_MARKETTRADEPERIOD = DESCRIPTOR.message_types_by_name['MarketTradePeriod']
_TRADEPERIOD = DESCRIPTOR.message_types_by_name['TradePeriod']
_SUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['SubscriptionRequest']
_SUBSCRIPTIONRESPONSE = DESCRIPTOR.message_types_by_name['SubscriptionResponse']
_SUBTYPELIST = DESCRIPTOR.message_types_by_name['SubTypeList']
_SUBSCRIBEREQUEST = DESCRIPTOR.message_types_by_name['SubscribeRequest']
_UNSUBSCRIBEREQUEST = DESCRIPTOR.message_types_by_name['UnsubscribeRequest']
_UNSUBSCRIBERESPONSE = DESCRIPTOR.message_types_by_name['UnsubscribeResponse']
_PUSHQUOTE = DESCRIPTOR.message_types_by_name['PushQuote']
_PUSHDEPTH = DESCRIPTOR.message_types_by_name['PushDepth']
_PUSHBROKERS = DESCRIPTOR.message_types_by_name['PushBrokers']
_PUSHTRADE = DESCRIPTOR.message_types_by_name['PushTrade']
_MARKETTRADEDAYREQUEST = DESCRIPTOR.message_types_by_name['MarketTradeDayRequest']
_MARKETTRADEDAYRESPONSE = DESCRIPTOR.message_types_by_name['MarketTradeDayResponse']
SecurityRequest = _reflection.GeneratedProtocolMessageType('SecurityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityRequest)
  })
_sym_db.RegisterMessage(SecurityRequest)

MultiSecurityRequest = _reflection.GeneratedProtocolMessageType('MultiSecurityRequest', (_message.Message,), {
  'DESCRIPTOR' : _MULTISECURITYREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.MultiSecurityRequest)
  })
_sym_db.RegisterMessage(MultiSecurityRequest)

SecurityStaticInfoResponse = _reflection.GeneratedProtocolMessageType('SecurityStaticInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYSTATICINFORESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityStaticInfoResponse)
  })
_sym_db.RegisterMessage(SecurityStaticInfoResponse)

StaticInfo = _reflection.GeneratedProtocolMessageType('StaticInfo', (_message.Message,), {
  'DESCRIPTOR' : _STATICINFO,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.StaticInfo)
  })
_sym_db.RegisterMessage(StaticInfo)

SecurityQuoteResponse = _reflection.GeneratedProtocolMessageType('SecurityQuoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYQUOTERESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityQuoteResponse)
  })
_sym_db.RegisterMessage(SecurityQuoteResponse)

SecurityQuote = _reflection.GeneratedProtocolMessageType('SecurityQuote', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYQUOTE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityQuote)
  })
_sym_db.RegisterMessage(SecurityQuote)

PrePostQuote = _reflection.GeneratedProtocolMessageType('PrePostQuote', (_message.Message,), {
  'DESCRIPTOR' : _PREPOSTQUOTE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.PrePostQuote)
  })
_sym_db.RegisterMessage(PrePostQuote)

OptionQuoteResponse = _reflection.GeneratedProtocolMessageType('OptionQuoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONQUOTERESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionQuoteResponse)
  })
_sym_db.RegisterMessage(OptionQuoteResponse)

OptionQuote = _reflection.GeneratedProtocolMessageType('OptionQuote', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONQUOTE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionQuote)
  })
_sym_db.RegisterMessage(OptionQuote)

OptionExtend = _reflection.GeneratedProtocolMessageType('OptionExtend', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONEXTEND,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionExtend)
  })
_sym_db.RegisterMessage(OptionExtend)

WarrantQuoteResponse = _reflection.GeneratedProtocolMessageType('WarrantQuoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTQUOTERESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.WarrantQuoteResponse)
  })
_sym_db.RegisterMessage(WarrantQuoteResponse)

WarrantQuote = _reflection.GeneratedProtocolMessageType('WarrantQuote', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTQUOTE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.WarrantQuote)
  })
_sym_db.RegisterMessage(WarrantQuote)

WarrantExtend = _reflection.GeneratedProtocolMessageType('WarrantExtend', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTEXTEND,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.WarrantExtend)
  })
_sym_db.RegisterMessage(WarrantExtend)

SecurityDepthResponse = _reflection.GeneratedProtocolMessageType('SecurityDepthResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYDEPTHRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityDepthResponse)
  })
_sym_db.RegisterMessage(SecurityDepthResponse)

Depth = _reflection.GeneratedProtocolMessageType('Depth', (_message.Message,), {
  'DESCRIPTOR' : _DEPTH,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.Depth)
  })
_sym_db.RegisterMessage(Depth)

SecurityBrokersResponse = _reflection.GeneratedProtocolMessageType('SecurityBrokersResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYBROKERSRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityBrokersResponse)
  })
_sym_db.RegisterMessage(SecurityBrokersResponse)

Brokers = _reflection.GeneratedProtocolMessageType('Brokers', (_message.Message,), {
  'DESCRIPTOR' : _BROKERS,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.Brokers)
  })
_sym_db.RegisterMessage(Brokers)

ParticipantBrokerIdsResponse = _reflection.GeneratedProtocolMessageType('ParticipantBrokerIdsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANTBROKERIDSRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.ParticipantBrokerIdsResponse)
  })
_sym_db.RegisterMessage(ParticipantBrokerIdsResponse)

ParticipantInfo = _reflection.GeneratedProtocolMessageType('ParticipantInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANTINFO,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.ParticipantInfo)
  })
_sym_db.RegisterMessage(ParticipantInfo)

SecurityTradeRequest = _reflection.GeneratedProtocolMessageType('SecurityTradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYTRADEREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityTradeRequest)
  })
_sym_db.RegisterMessage(SecurityTradeRequest)

SecurityTradeResponse = _reflection.GeneratedProtocolMessageType('SecurityTradeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYTRADERESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityTradeResponse)
  })
_sym_db.RegisterMessage(SecurityTradeResponse)

Trade = _reflection.GeneratedProtocolMessageType('Trade', (_message.Message,), {
  'DESCRIPTOR' : _TRADE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.Trade)
  })
_sym_db.RegisterMessage(Trade)

SecurityIntradayRequest = _reflection.GeneratedProtocolMessageType('SecurityIntradayRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYINTRADAYREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityIntradayRequest)
  })
_sym_db.RegisterMessage(SecurityIntradayRequest)

SecurityIntradayResponse = _reflection.GeneratedProtocolMessageType('SecurityIntradayResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYINTRADAYRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityIntradayResponse)
  })
_sym_db.RegisterMessage(SecurityIntradayResponse)

Line = _reflection.GeneratedProtocolMessageType('Line', (_message.Message,), {
  'DESCRIPTOR' : _LINE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.Line)
  })
_sym_db.RegisterMessage(Line)

SecurityCandlestickRequest = _reflection.GeneratedProtocolMessageType('SecurityCandlestickRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYCANDLESTICKREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityCandlestickRequest)
  })
_sym_db.RegisterMessage(SecurityCandlestickRequest)

SecurityCandlestickResponse = _reflection.GeneratedProtocolMessageType('SecurityCandlestickResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYCANDLESTICKRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SecurityCandlestickResponse)
  })
_sym_db.RegisterMessage(SecurityCandlestickResponse)

Candlestick = _reflection.GeneratedProtocolMessageType('Candlestick', (_message.Message,), {
  'DESCRIPTOR' : _CANDLESTICK,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.Candlestick)
  })
_sym_db.RegisterMessage(Candlestick)

OptionChainDateListResponse = _reflection.GeneratedProtocolMessageType('OptionChainDateListResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONCHAINDATELISTRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionChainDateListResponse)
  })
_sym_db.RegisterMessage(OptionChainDateListResponse)

OptionChainDateStrikeInfoRequest = _reflection.GeneratedProtocolMessageType('OptionChainDateStrikeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONCHAINDATESTRIKEINFOREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionChainDateStrikeInfoRequest)
  })
_sym_db.RegisterMessage(OptionChainDateStrikeInfoRequest)

OptionChainDateStrikeInfoResponse = _reflection.GeneratedProtocolMessageType('OptionChainDateStrikeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONCHAINDATESTRIKEINFORESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.OptionChainDateStrikeInfoResponse)
  })
_sym_db.RegisterMessage(OptionChainDateStrikeInfoResponse)

StrikePriceInfo = _reflection.GeneratedProtocolMessageType('StrikePriceInfo', (_message.Message,), {
  'DESCRIPTOR' : _STRIKEPRICEINFO,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.StrikePriceInfo)
  })
_sym_db.RegisterMessage(StrikePriceInfo)

IssuerInfoResponse = _reflection.GeneratedProtocolMessageType('IssuerInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISSUERINFORESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.IssuerInfoResponse)
  })
_sym_db.RegisterMessage(IssuerInfoResponse)

IssuerInfo = _reflection.GeneratedProtocolMessageType('IssuerInfo', (_message.Message,), {
  'DESCRIPTOR' : _ISSUERINFO,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.IssuerInfo)
  })
_sym_db.RegisterMessage(IssuerInfo)

WarrantFilterListRequest = _reflection.GeneratedProtocolMessageType('WarrantFilterListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTFILTERLISTREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.WarrantFilterListRequest)
  })
_sym_db.RegisterMessage(WarrantFilterListRequest)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)

WarrantFilterListResponse = _reflection.GeneratedProtocolMessageType('WarrantFilterListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTFILTERLISTRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.WarrantFilterListResponse)
  })
_sym_db.RegisterMessage(WarrantFilterListResponse)

FilterWarrant = _reflection.GeneratedProtocolMessageType('FilterWarrant', (_message.Message,), {
  'DESCRIPTOR' : _FILTERWARRANT,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.FilterWarrant)
  })
_sym_db.RegisterMessage(FilterWarrant)

MarketTradePeriodResponse = _reflection.GeneratedProtocolMessageType('MarketTradePeriodResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTRADEPERIODRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.MarketTradePeriodResponse)
  })
_sym_db.RegisterMessage(MarketTradePeriodResponse)

MarketTradePeriod = _reflection.GeneratedProtocolMessageType('MarketTradePeriod', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTRADEPERIOD,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.MarketTradePeriod)
  })
_sym_db.RegisterMessage(MarketTradePeriod)

TradePeriod = _reflection.GeneratedProtocolMessageType('TradePeriod', (_message.Message,), {
  'DESCRIPTOR' : _TRADEPERIOD,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.TradePeriod)
  })
_sym_db.RegisterMessage(TradePeriod)

SubscriptionRequest = _reflection.GeneratedProtocolMessageType('SubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTIONREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SubscriptionRequest)
  })
_sym_db.RegisterMessage(SubscriptionRequest)

SubscriptionResponse = _reflection.GeneratedProtocolMessageType('SubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTIONRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SubscriptionResponse)
  })
_sym_db.RegisterMessage(SubscriptionResponse)

SubTypeList = _reflection.GeneratedProtocolMessageType('SubTypeList', (_message.Message,), {
  'DESCRIPTOR' : _SUBTYPELIST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SubTypeList)
  })
_sym_db.RegisterMessage(SubTypeList)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.SubscribeRequest)
  })
_sym_db.RegisterMessage(SubscribeRequest)

UnsubscribeRequest = _reflection.GeneratedProtocolMessageType('UnsubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBEREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.UnsubscribeRequest)
  })
_sym_db.RegisterMessage(UnsubscribeRequest)

UnsubscribeResponse = _reflection.GeneratedProtocolMessageType('UnsubscribeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBERESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.UnsubscribeResponse)
  })
_sym_db.RegisterMessage(UnsubscribeResponse)

PushQuote = _reflection.GeneratedProtocolMessageType('PushQuote', (_message.Message,), {
  'DESCRIPTOR' : _PUSHQUOTE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.PushQuote)
  })
_sym_db.RegisterMessage(PushQuote)

PushDepth = _reflection.GeneratedProtocolMessageType('PushDepth', (_message.Message,), {
  'DESCRIPTOR' : _PUSHDEPTH,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.PushDepth)
  })
_sym_db.RegisterMessage(PushDepth)

PushBrokers = _reflection.GeneratedProtocolMessageType('PushBrokers', (_message.Message,), {
  'DESCRIPTOR' : _PUSHBROKERS,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.PushBrokers)
  })
_sym_db.RegisterMessage(PushBrokers)

PushTrade = _reflection.GeneratedProtocolMessageType('PushTrade', (_message.Message,), {
  'DESCRIPTOR' : _PUSHTRADE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.PushTrade)
  })
_sym_db.RegisterMessage(PushTrade)

MarketTradeDayRequest = _reflection.GeneratedProtocolMessageType('MarketTradeDayRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTRADEDAYREQUEST,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.MarketTradeDayRequest)
  })
_sym_db.RegisterMessage(MarketTradeDayRequest)

MarketTradeDayResponse = _reflection.GeneratedProtocolMessageType('MarketTradeDayResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTRADEDAYRESPONSE,
  '__module__' : 'quote.api_pb2'
  # @@protoc_insertion_point(class_scope:longbridgeapp.quote.v1.MarketTradeDayResponse)
  })
_sym_db.RegisterMessage(MarketTradeDayResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.longbridgeapp.quote.v1B\010ApiProtoP\001Z?github.com/longbridgeapp/openapi-protobufs/gen/go/quote;quotev1\242\002\003LQX\252\002\026Longbridgeapp.Quote.V1\312\002\026Longbridgeapp\\Quote\\V1\342\002\"Longbridgeapp\\Quote\\V1\\GPBMetadata\352\002\030Longbridgeapp::Quote::V1'
  _COMMAND._serialized_start=9376
  _COMMAND._serialized_end=9966
  _TRADESTATUS._serialized_start=9969
  _TRADESTATUS._serialized_end=10163
  _TRADESESSION._serialized_start=10165
  _TRADESESSION._serialized_end=10228
  _ADJUSTTYPE._serialized_start=10230
  _ADJUSTTYPE._serialized_end=10277
  _PERIOD._serialized_start=10280
  _PERIOD._serialized_end=10442
  _SUBTYPE._serialized_start=10444
  _SUBTYPE._serialized_end=10517
  _SECURITYREQUEST._serialized_start=43
  _SECURITYREQUEST._serialized_end=84
  _MULTISECURITYREQUEST._serialized_start=86
  _MULTISECURITYREQUEST._serialized_end=132
  _SECURITYSTATICINFORESPONSE._serialized_start=134
  _SECURITYSTATICINFORESPONSE._serialized_end=240
  _STATICINFO._serialized_start=243
  _STATICINFO._serialized_end=728
  _SECURITYQUOTERESPONSE._serialized_start=730
  _SECURITYQUOTERESPONSE._serialized_end=823
  _SECURITYQUOTE._serialized_start=826
  _SECURITYQUOTE._serialized_end=1299
  _PREPOSTQUOTE._serialized_start=1302
  _PREPOSTQUOTE._serialized_end=1496
  _OPTIONQUOTERESPONSE._serialized_start=1498
  _OPTIONQUOTERESPONSE._serialized_end=1587
  _OPTIONQUOTE._serialized_start=1590
  _OPTIONQUOTE._serialized_end=1974
  _OPTIONEXTEND._serialized_start=1977
  _OPTIONEXTEND._serialized_end=2394
  _WARRANTQUOTERESPONSE._serialized_start=2396
  _WARRANTQUOTERESPONSE._serialized_end=2487
  _WARRANTQUOTE._serialized_start=2490
  _WARRANTQUOTE._serialized_end=2878
  _WARRANTEXTEND._serialized_start=2881
  _WARRANTEXTEND._serialized_end=3376
  _SECURITYDEPTHRESPONSE._serialized_start=3379
  _SECURITYDEPTHRESPONSE._serialized_end=3524
  _DEPTH._serialized_start=3526
  _DEPTH._serialized_end=3636
  _SECURITYBROKERSRESPONSE._serialized_start=3639
  _SECURITYBROKERSRESPONSE._serialized_end=3820
  _BROKERS._serialized_start=3822
  _BROKERS._serialized_end=3890
  _PARTICIPANTBROKERIDSRESPONSE._serialized_start=3893
  _PARTICIPANTBROKERIDSRESPONSE._serialized_end=4026
  _PARTICIPANTINFO._serialized_start=4029
  _PARTICIPANTINFO._serialized_end=4221
  _SECURITYTRADEREQUEST._serialized_start=4223
  _SECURITYTRADEREQUEST._serialized_end=4291
  _SECURITYTRADERESPONSE._serialized_start=4293
  _SECURITYTRADERESPONSE._serialized_end=4395
  _TRADE._serialized_start=4398
  _TRADE._serialized_end=4617
  _SECURITYINTRADAYREQUEST._serialized_start=4619
  _SECURITYINTRADAYREQUEST._serialized_end=4668
  _SECURITYINTRADAYRESPONSE._serialized_start=4670
  _SECURITYINTRADAYRESPONSE._serialized_end=4772
  _LINE._serialized_start=4775
  _LINE._serialized_end=4914
  _SECURITYCANDLESTICKREQUEST._serialized_start=4917
  _SECURITYCANDLESTICKREQUEST._serialized_end=5116
  _SECURITYCANDLESTICKRESPONSE._serialized_start=5118
  _SECURITYCANDLESTICKRESPONSE._serialized_end=5244
  _CANDLESTICK._serialized_start=5247
  _CANDLESTICK._serialized_end=5422
  _OPTIONCHAINDATELISTRESPONSE._serialized_start=5424
  _OPTIONCHAINDATELISTRESPONSE._serialized_end=5486
  _OPTIONCHAINDATESTRIKEINFOREQUEST._serialized_start=5488
  _OPTIONCHAINDATESTRIKEINFOREQUEST._serialized_end=5579
  _OPTIONCHAINDATESTRIKEINFORESPONSE._serialized_start=5581
  _OPTIONCHAINDATESTRIKEINFORESPONSE._serialized_end=5701
  _STRIKEPRICEINFO._serialized_start=5704
  _STRIKEPRICEINFO._serialized_end=5835
  _ISSUERINFORESPONSE._serialized_start=5837
  _ISSUERINFORESPONSE._serialized_end=5926
  _ISSUERINFO._serialized_start=5928
  _ISSUERINFO._serialized_end=6031
  _WARRANTFILTERLISTREQUEST._serialized_start=6034
  _WARRANTFILTERLISTREQUEST._serialized_end=6187
  _FILTERCONFIG._serialized_start=6190
  _FILTERCONFIG._serialized_end=6456
  _WARRANTFILTERLISTRESPONSE._serialized_start=6459
  _WARRANTFILTERLISTRESPONSE._serialized_end=6593
  _FILTERWARRANT._serialized_start=6596
  _FILTERWARRANT._serialized_end=7421
  _MARKETTRADEPERIODRESPONSE._serialized_start=7423
  _MARKETTRADEPERIODRESPONSE._serialized_end=7543
  _MARKETTRADEPERIOD._serialized_start=7545
  _MARKETTRADEPERIOD._serialized_end=7662
  _TRADEPERIOD._serialized_start=7665
  _TRADEPERIOD._serialized_end=7807
  _SUBSCRIPTIONREQUEST._serialized_start=7809
  _SUBSCRIPTIONREQUEST._serialized_end=7830
  _SUBSCRIPTIONRESPONSE._serialized_start=7832
  _SUBSCRIPTIONRESPONSE._serialized_end=7918
  _SUBTYPELIST._serialized_start=7920
  _SUBTYPELIST._serialized_end=8017
  _SUBSCRIBEREQUEST._serialized_start=8020
  _SUBSCRIBEREQUEST._serialized_end=8158
  _UNSUBSCRIBEREQUEST._serialized_start=8161
  _UNSUBSCRIBEREQUEST._serialized_end=8294
  _UNSUBSCRIBERESPONSE._serialized_start=8296
  _UNSUBSCRIBERESPONSE._serialized_end=8317
  _PUSHQUOTE._serialized_start=8320
  _PUSHQUOTE._serialized_end=8699
  _PUSHDEPTH._serialized_start=8702
  _PUSHDEPTH._serialized_end=8863
  _PUSHBROKERS._serialized_start=8866
  _PUSHBROKERS._serialized_end=9063
  _PUSHTRADE._serialized_start=9065
  _PUSHTRADE._serialized_end=9181
  _MARKETTRADEDAYREQUEST._serialized_start=9183
  _MARKETTRADEDAYREQUEST._serialized_end=9280
  _MARKETTRADEDAYRESPONSE._serialized_start=9282
  _MARKETTRADEDAYRESPONSE._serialized_end=9373
# @@protoc_insertion_point(module_scope)
