/// Subscribe Topics
pub(crate) const SUBSCRIBE: u8 = 16;

/// Unsubscribe Topics
pub(crate) const UNSUBSCRIBE: u8 = 17;

/// Push Notification
///
/// Reference: <https://open.longbridgeapp.com/en/docs/trade/trade-push#push-notification>
pub(crate) const PUSH_NOTIFICATION: u8 = 18;
